netanchor_testing library

Testing utilities for netanchor consumers.

Classes

MockAdapter
Test-only HttpAdapter that returns canned responses and records every request it received.
MockReply
Represents one entry in a mixed sequence given to StubBuilder.thenRespond.
StubBuilder
Fluent terminator returned by MockAdapter.when.