MockReply class

Represents one entry in a mixed sequence given to StubBuilder.thenRespond.

Constructors

MockReply.failure(HttpAdapterException exception)
Reply by throwing exception.
const
MockReply.success(HttpResponse response)
Reply with response.
const

Properties

exception HttpAdapterException?
Either the exception or null if response is set.
final
hashCode int
The hash code for this object.
no setterinherited
response HttpResponse?
Either the response or null if exception is set.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited